`pause` <-
function () 
{
    cat("Press <Enter> to continue...")
    readline()
    invisible()
}

